==> FHLBBS-4.8.tgz: wbbs/boards.c <==
#include "cgic.h"
#include "wbbs.c"
/***************   ΨˬdQװϤ峹O_Q\ŪL *************/
int
brc_unread(fname)
  char *fname;
{
  int ftime, n;

  ftime = atoi(&fname[2]);
  if (ftime <= 0)
    return 0;
  if (brc_num <= 0)
    return 1;
  for (n = 0; n < brc_num; n++)
  {
    if (ftime > brc_list[n])
      return 1;
    else if (ftime == brc_list[n])
      return 0;
  }
  return 0;
}

int cgiMain() {
   FILE *fptr1,*fptr2, *fptr3;
   char buf1[256];
   char buf2[256];
   int ptmode;
   char *foo,board1[20],path1[100];
   char oneline[301];
   char *bdname;
   char *pt1,*pt2;
   time_t t1;
   int len1, fd, numposts, i=0,j, count, start = 999999, end1, numarticle;
   struct fileheader postfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   int querymode=0;//=0 use number to query, =1 top =2 pgup =3 pgdn =4 bottom
   int searchmode=0; //=1 Search mode =0 normal mode
   int isresearch=0,hitnum=0,showwelcome=0,reload=0;
   long fid;
   time_t board_note_time;
   time_t board_visit_time;

   strncpy(currboard,getenv("QUERY_STRING"),IDLEN+IDLEN);
   if (pt1=strstr(currboard,"_reload")) /*MreloadѼ*/
	{reload=1;
	 *pt1=0;
	}
   if (pt1=strstr(currboard,"QUERY")) *pt1=0;/*MQueryѼ*/
   if (pt1=strstr(currboard,"&QUERY")) *pt1=0;	
   currboard[IDLEN+IDLEN]=0;

    /** Bz}l   **/
   if(foo = rindex(currboard, '$')){
	if (strstr(currboard,"top")) querymode=1;
        else if (strstr(currboard,"pgup")) querymode=2;
        else if (strstr(currboard,"pgdn")) querymode=3;
        else if (strstr(currboard,"bottom")) querymode=4;
	else 
     {
       start = atoi(foo + 1);
       querymode=0;
     }
	  *foo = '\0';
   }
    /**** MΪ ***/
  cgiFormString("QUERY",searchtext,63); /*pG QueryѼƨSCXӡANOM*/
   if (searchtext[0]) searchmode=1;
   else searchmode=0;

   if(!check_passwd())
       return(0);
   /**** pGOĤ@iӴNshow we***/
    if (strcmp(currboard,Cboardout)&&currboard[0]&&(reload==0)) showwelcome=1;
    else showwelcome=0;
   /*** pGQװϨSWrNcookie ***/
   if (currboard[0]==0)
   {
	strcpy(currboard,Cboardout);
	//start=999999;
   }

   if (strrchr(currboard,'/')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }
  
   bdname=currboard;
   bp = getbcache(bdname);
   /** ˬd@USŪQװϪvAHΰQװϦS **/
   if ((!bp)||(!Ben_Perm(bp)))
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
      return(0);
   }
   /*** show we ***/
   board_note_time = bp->bupdate;
   board_visit_time = time(0);
   if ((showwelcome)&&(board_visit_time < board_note_time)) 
   {
      sprintf(path1,BBSHOME "/boards/%s/notes.html", currboard);
      if ((fptr2=fopen(path1,"r"))==NULL)
      {
        sprintf(path1,BBSHOME "/boards/%s/notes", currboard);
        if ((fptr2=fopen(path1,"r"))!=NULL)
        {
   	       strcpy(Cboardin,currboard);
   	       check_passwd();
               cgiHeaderContentType("text/html");
	    //fprintf(cgiOut,"1.%s 2.%s 3.%s",Cboardin,Cboardout,currboard);
		pfile(fptr2);
	        fclose(fptr2);
	  fprintf(cgiOut,"<center><form method=\"post\" "
          "action=/cgi-bin/boards.cgi?%s_reload>"
	  "<input type=\"submit\" name=\"sub\" value=\"BiJQװ\">",
	  getenv("QUERY_STRING"));
	  return 0;
	}
      }	
      else
      {
   	  strcpy(Cboardin,currboard);
   	  check_passwd();
            cgiHeaderContentType("text/html");
		pfile(fptr2);
	        fclose(fptr2);
	  fprintf(cgiOut,"<center><form method=\"post\" "
          "action=/cgi-bin/boards.cgi?%s_reload>"
	  "<input type=\"submit\" name=\"sub\" value=\"BiJQװ\">",
	  getenv("QUERY_STRING"));
	  return 0;
      }
	
   }  
   sprintf(path1,BBSHOME "/boards/%s/.DIR", currboard);
  
   if( stat(path1, &st ) >= 0 )
	  numposts = st.st_size / (sizeof( struct fileheader ));
   else
	  numposts = 0;

   if (querymode==2)
	start=(Cookienumout-SHOWNUM > 0) ? (Cookienumout-SHOWNUM) : 1;
   else if (querymode==3) 
      start=(Cookienumout+SHOWNUM < numposts-SHOWNUM) ? 
            (Cookienumout+SHOWNUM) : numposts-SHOWNUM;
   else if (querymode==1) start=1;
   else if (querymode==4) start= numposts-SHOWNUM;
   /**** ~iH post 峹Fi ***/
   cgiFormIntegerBounded("numarticle",&numarticle,1,numposts,start);
   start = numarticle;
   if(start == 999999)
	  start = (numposts - SHOWNUM > 0) ? (numposts - SHOWNUM) : 1;
   else if(start <= 0)
	  start = 1;
    /*** gJsQװϻPظX ***/
   Cookienumin=start;
   strcpy(Cboardin,currboard);
   if(!check_passwd())
       return(0);
   cgiHeaderContentType("text/html");
   strcpy(buf1, currboard);
  
    /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   sprintf(buf2, "%s%s",DEFDIR,BOARDPRE);
   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0;
    
   }
   /* Ū~ɮסAӭn令Ū榡 **/
   
    while(fgets(oneline, 300, fptr2) != NULL)  /*}lBz榡 ****/
    {
      pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
            /***********************
            if (bp->BM[0])
            fprintf(cgiOut, "<hr>Qװ: %s  D: %s OD: %s<p><table>\n",
	        currboard,bp->title+5,bp->BM);
            else
            fprintf(cgiOut, "<hr>Qװ: %s  D: %s OD: xD<p>\n",
	        currboard,bp->title);
            *********************/
            fprintf(cgiOut, "<table><tr><td>s</td><td>Ū</td><td>@</td>"
            "<td></td><td>D</td></tr>\n");
           
            /** MҦ**/   
            if (searchmode)
            {
                sprintf(buf1,BBSHOME "/home/%s/search.result", cuser.userid);
                if ((fptr1=fopen(buf1,"r"))==NULL) isresearch=1;
                else
                {
                  fgets(buf1, 255, fptr1);/* read boards */
                  sscanf(buf1,"%s",buf2);
                  if (strcmp(buf2,currboard)) isresearch=1;
                  fgets(buf1, 255, fptr1);/* read query string */
                  sscanf(buf1,"%s",buf2);
                  if (strcmp(buf2,searchtext)) isresearch=1;
                  fclose(fptr1);
                }
                sprintf(buf1,BBSHOME "/home/%s/search.result", cuser.userid);
                if ((fptr1=fopen(buf1,"r+"))==NULL)
                {
		   /****Ĥ@} **/
		   if ((fptr1=fopen(buf1,"a+"))==NULL)
		   {
                     fprintf(cgiOut,"%sLk}ҡI<br>\n",buf1);
                     return(0);
		   }
		   fclose(fptr1);
		   fptr1=fopen(buf1,"r+");
                }
                if (isresearch)/* T{nsͷjM **/
                {
                    
                    fprintf(fptr1,"%s\n%s\n00000\n00001\n0000000000\n",
                    currboard,searchtext);
                     /* Ū .DIR  */
                     sprintf(buf1,BBSHOME "/boards/%s/.DIR", currboard);
                     if( (fd = open( buf1, O_RDONLY )) != -1 )
                     {
                        for (j=1;j<=numposts;j++)
                        {
                            read(fd,&postfile,sizeof(postfile));
                            if (strstr(postfile.owner,searchtext)||
                                strstr(postfile.title,searchtext))
                            {
                              sscanf(postfile.filename,"M.%s.A",buf2);
                              t1=atoi(buf2);
                              strncpy(buf1,ctime(&t1)+4,6);
                              buf1[6] = '\0';
                              if (strcmp(currboard,"comfortable")==0)
                              fprintf(fptr1,"<tr><td>%3d.</td><td>%s</td>"
                              "<td>%-15s</td><td>%-5s</td>"
                              ,j, brc_unread(postfile.filename)?"":"","",buf1);
 	                          else
                                fprintf(fptr1,"<tr><td>%3d.</td><td>%s</td>"
                                "<td>%-15s</td><td>%-5s</td>"
                                , j, brc_unread(postfile.filename)?"":""
                                ,postfile.owner,buf1);
                              fprintf(fptr1,"<td><a href=\"read.cgi?%s_%d\">%s</a></td></tr>\n", 
                              currboard, j, postfile.title);
                              hitnum++;
                            }
                        } /* for j */
                        close(fd);
                     } /* open fd */
                     /*** o椣çAOΨѧO̫@檺 ****/
                     fprintf(fptr1,"<tr><td>SƤFI</td><tr>\n");
                     fseek(fptr1,0,SEEK_SET);
                     fgets(buf1, 255, fptr1);/* read boards */
                     fgets(buf1, 255, fptr1);/* read search text */
                     fprintf(fptr1,"%05d\n",hitnum); /** write total record */
                     fgets(buf1, 255, fptr1);/* read begin record */
                     fid=ftell(fptr1);
                     fprintf(fptr1,"%010ld\n",fid+11); /* write begin position */
                     fseek(fptr1,0,SEEK_SET);
                }/* if isresearch **/
                
                fgets(buf1, 255, fptr1);/* read boards */
                //fprintf(cgiOut,"boards=%s<br>",buf1);
                fgets(buf1, 255, fptr1);/* read search text */
                //fprintf(cgiOut,"search=%s<br>",buf1);
                fgets(buf1, 255, fptr1);/** read hitnum **/
               //fprintf(cgiOut,"hitnum=%s<br>",buf1);
                hitnum=atoi(buf1);
                fgets(buf1, 255, fptr1);/** read startnum **/
                start=atoi(buf1);
                fgets(buf1, 255, fptr1);/** read file position **/
                fid=atol(buf1);
                if (isresearch) start=1;
                else 
                {
                    if (start>hitnum) start=hitnum;
                }
                end1 = (start + SHOWNUM > hitnum) ? hitnum : (start + SHOWNUM);
                fseek(fptr1,fid,SEEK_SET);
                /******
                fprintf(cgiOut,"start=%d,end=%d,hitnum=%d fid=%ld",
                start,end1,hitnum,fid);
                ******/
                for(j = start;j <= end1;j++) 
                {
                    fgets(buf1, 255, fptr1);/* read data */
                    fprintf(cgiOut,"%s",buf1);
                }
                if (strncmp(buf1+8,"SƤFI",12)) fid=ftell(fptr1);
                fseek(fptr1,0,SEEK_SET);
                fgets(buf1, 255, fptr1);/* read boards */
                fgets(buf1, 255, fptr1);/* read search text */
                fgets(buf1, 255, fptr1);/* read total record */
                fprintf(fptr1,"%05d\n",end1+1); /** write begin record */
                fprintf(fptr1,"%010ld\n",fid); /* write begin position */
                fprintf(cgiOut,"</table>");
                fclose(fptr1);
                
            } /* search mode **/
            else
            {
            /* Ū .DIR  */
            sprintf(buf1,BBSHOME "/boards/%s/.DIR", currboard);
            brc_initial(currboard);
            if( (fd = open( buf1, O_RDONLY )) != -1 )
            {
            lseek(fd, sizeof(struct fileheader)*(start-1), SEEK_SET);
            end1 = (start + SHOWNUM > numposts) ? numposts : (start + SHOWNUM);
           /***** }lLC@ ***/
            for(j = start;j <= end1;j++) 
            {
              read(fd,&postfile,sizeof(postfile));
              sscanf(postfile.filename,"M.%s.A",buf2);
              t1=atoi(buf2);
              strncpy(buf1,ctime(&t1)+4,6);
               buf1[6] = '\0';
              if (strcmp(currboard,"comfortable")==0)
              fprintf(cgiOut,"<tr><td>%3d.</td><td>%s</td>"
              "<td>%-15s</td><td>%-5s</td>"
             , j, brc_unread(postfile.filename)?"":"","",buf1);
 	          else
              fprintf(cgiOut,"<tr><td>%3d.</td><td>%s</td>"
              "<td>%-15s</td><td>%-5s</td>"
              , j, brc_unread(postfile.filename)?"":"",postfile.owner,buf1);
              fprintf(cgiOut,"<td><a href=\"read.cgi?%s_%d\">%s</a></td></tr>\n", 
              currboard, j, postfile.title);
            }
            fprintf(cgiOut,"</table>");
            close(fd);
           }/* endif(fd) */
           else
          { fprintf(cgiOut,"%sؿ}ҿ~I<p>",buf1);
          }

           /***** Oi ************/
          setbfile(buf1,currboard,"wenternum");
          logcnt(buf1);
         } 
         } /* else searchmode */
         else // other mode
            SSI(ptmode);
      }
      fprintf(cgiOut,"%s", pt1);
    }
   fclose(fptr2);
   
   
}

==> FHLBBS-5.3.tgz: wbbs/boards.c <==
#include "cgic.h"
#include "wbbs.c"
/***************   ΨˬdQװϤ峹O_Q\ŪL *************/
int
brc_unread(fname)
  char *fname;
{
  int ftime, n;

  ftime = atoi(&fname[2]);
  if (ftime <= 0)
    return 0;
  if (brc_num <= 0)
    return 1;
  for (n = 0; n < brc_num; n++)
  {
    if (ftime > brc_list[n])
      return 1;
    else if (ftime == brc_list[n])
      return 0;
  }
  return 0;
}

int cgiMain() {
   FILE *fptr1,*fptr2, *fptr3;
   char buf1[256];
   char buf2[256];
   int ptmode;
   char *foo,board1[20],path1[100];
   char oneline[301];
   char *bdname;
   char *pt1,*pt2;
   time_t t1;
   int len1, fd, numposts, i=0,j, count, start = 999999, end1, numarticle;
   struct fileheader postfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   int querymode=0;//=0 use number to query, =1 top =2 pgup =3 pgdn =4 bottom
   int searchmode=0; //=1 Search mode =0 normal mode
   int isresearch=0,hitnum=0,showwelcome=0,reload=0;
   long fid;
   time_t board_note_time;
   time_t board_visit_time;

   strncpy(currboard,getenv("QUERY_STRING"),IDLEN+IDLEN);
   if (pt1=strstr(currboard,"_reload")) /*MreloadѼ*/
	{reload=1;
	 *pt1=0;
	}
   if (pt1=strstr(currboard,"&QUERY")) *pt1=0;	
   if (pt1=strstr(currboard,"QUERY")) *pt1=0;/*MQueryѼ*/
   if (pt1=strstr(currboard,"&DOORID")) *pt1=0;	
   if (pt1=strstr(currboard,"DOORID")) *pt1=0;/*MDOORIDѼ*/
   currboard[IDLEN+IDLEN]=0;

    /** Bz}l   **/
   if(foo = rindex(currboard, '$')){
	if (strstr(currboard,"top")) querymode=1;
        else if (strstr(currboard,"pgup")) querymode=2;
        else if (strstr(currboard,"pgdn")) querymode=3;
        else if (strstr(currboard,"bottom")) querymode=4;
	else 
     {
       start = atoi(foo + 1);
       querymode=0;
     }
	  *foo = '\0';
   }
    /**** MΪ ***/
  cgiFormString("QUERY",searchtext,63); /*pG QueryѼƨSCXӡANOM*/
   if (searchtext[0]) searchmode=1;
   else searchmode=0;
   strcpy(Cboardin,currboard);
   if(!check_passwd())
       return(0);
   /**** pGOĤ@iӴNshow we***/
    if (strcmp(currboard,Cboardout)&&currboard[0]&&(reload==0)) showwelcome=1;
    else showwelcome=0;
   /*** pGQװϨSWrNcookie ***/
   if (currboard[0]==0)
   {
	strcpy(currboard,Cboardout);
	//start=999999;
   }

   if (strrchr(currboard,'/')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }
  
   bdname=currboard;
   bp = getbcache(bdname);
   /** ˬd@USŪQװϪvAHΰQװϦS **/
   if ((!bp)||(!Ben_Perm(bp)))
   {
	/********* add by tjm ***************/
      if ((strcmp(cuser.userid,"guest")==0)&&(!Ben_Perm(bp)))
      {
                authwin();
                return(0);
      }
      /***************************************/
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
      return(0);
   }
   /*** show we ***/
   board_note_time = bp->bupdate;
   board_visit_time = time(0);
   if ((showwelcome)&&(board_visit_time < board_note_time)) 
   {
      sprintf(path1,BBSHOME "/boards/%s/notes.html", currboard);
      if ((fptr2=fopen(path1,"r"))==NULL)
      {
        sprintf(path1,BBSHOME "/boards/%s/notes", currboard);
        if ((fptr2=fopen(path1,"r"))!=NULL)
        {
   	       //strcpy(Cboardin,currboard);
   	       //check_passwd();
               cgiHeaderContentType("text/html");
	    //fprintf(cgiOut,"1.%s 2.%s 3.%s",Cboardin,Cboardout,currboard);
		pfile(fptr2);
	        fclose(fptr2);
	  fprintf(cgiOut,"<center><form method=\"post\" "
          "action=/cgi-bin/boards.cgi?%s_reload>"
	  "<input type=\"submit\" name=\"sub\" value=\"BiJQװ\">",
	  getenv("QUERY_STRING"));
	  return 0;
	}
      }	
      else
      {
   	  //strcpy(Cboardin,currboard);
   	  //check_passwd();
            cgiHeaderContentType("text/html");
		pfile(fptr2);
	        fclose(fptr2);
	  fprintf(cgiOut,"<center><form method=\"post\" "
          "action=/cgi-bin/boards.cgi?%s_reload>"
	  "<input type=\"submit\" name=\"sub\" value=\"BiJQװ\">",
	  getenv("QUERY_STRING"));
	  return 0;
      }
	
   }  
   sprintf(path1,BBSHOME "/boards/%s/.DIR", currboard);
  
   if( stat(path1, &st ) >= 0 )
	  numposts = st.st_size / (sizeof( struct fileheader ));
   else
	  numposts = 0;

   if (querymode==2)
	start=(Cookienumout-SHOWNUM > 0) ? (Cookienumout-SHOWNUM) : 1;
   else if (querymode==3) 
      start=(Cookienumout+SHOWNUM < numposts-SHOWNUM) ? 
            (Cookienumout+SHOWNUM) : numposts-SHOWNUM;
   else if (querymode==1) start=1;
   else if (querymode==4) start= numposts-SHOWNUM;
   /**** ~iH post 峹Fi ***/
   cgiFormIntegerBounded("numarticle",&numarticle,1,numposts,start);
   start = numarticle;
   if(start == 999999)
	  start = (numposts - SHOWNUM > 0) ? (numposts - SHOWNUM) : 1;
   else if(start <= 0)
	  start = 1;
    /*** gJsQװϻPظX ***/
   Cookienumin=start;
   //strcpy(Cboardin,currboard);
   /*****oӭnbBz@ cookie O]IEAҥHF******/
   if(!check_passwd())
       return(0);
   cgiHeaderContentType("text/html");
   strcpy(buf1, currboard);
  
    /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   sprintf(buf2, "%s%s",DEFDIR[doorid],BOARDPRE);
   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0;
    
   }
   /* Ū~ɮסAӭn令Ū榡 **/
   
    while(fgets(oneline, 300, fptr2) != NULL)  /*}lBz榡 ****/
    {
      pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
            /***********************
            if (bp->BM[0])
            fprintf(cgiOut, "<hr>Qװ: %s  D: %s OD: %s<p><table>\n",
	        currboard,bp->title+5,bp->BM);
            else
            fprintf(cgiOut, "<hr>Qװ: %s  D: %s OD: xD<p>\n",
	        currboard,bp->title);
            *********************/
            fprintf(cgiOut, "<table><tr><td>s</td><td>Ū</td><td>@</td>"
            "<td></td><td>D</td></tr>\n");
           
            /** MҦ**/   
            if (searchmode)
            {
                sprintf(buf1,BBSHOME "/home/%s/search.result", cuser.userid);
                if ((fptr1=fopen(buf1,"r"))==NULL) isresearch=1;
                else
                {
                  fgets(buf1, 255, fptr1);/* read boards */
                  sscanf(buf1,"%s",buf2);
                  if (strcmp(buf2,currboard)) isresearch=1;
                  fgets(buf1, 255, fptr1);/* read query string */
                  sscanf(buf1,"%s",buf2);
                  if (strcmp(buf2,searchtext)) isresearch=1;
                  fclose(fptr1);
                }
                sprintf(buf1,BBSHOME "/home/%s/search.result", cuser.userid);
                if ((fptr1=fopen(buf1,"r+"))==NULL)
                {
		   /****Ĥ@} **/
		   if ((fptr1=fopen(buf1,"a+"))==NULL)
		   {
                     fprintf(cgiOut,"%sLk}ҡI<br>\n",buf1);
                     return(0);
		   }
		   fclose(fptr1);
		   fptr1=fopen(buf1,"r+");
                }
                if (isresearch)/* T{nsͷjM **/
                {
                    
                    fprintf(fptr1,"%s\n%s\n00000\n00001\n0000000000\n",
                    currboard,searchtext);
                     /* Ū .DIR  */
                     sprintf(buf1,BBSHOME "/boards/%s/.DIR", currboard);
                     if( (fd = open( buf1, O_RDONLY )) != -1 )
                     {
                        for (j=1;j<=numposts;j++)
                        {
                            read(fd,&postfile,sizeof(postfile));
                            if (strstr(postfile.owner,searchtext)||
                                strstr(postfile.title,searchtext))
                            {
                              sscanf(postfile.filename,"M.%s.A",buf2);
                              t1=atoi(buf2);
                              strncpy(buf1,ctime(&t1)+4,6);
                              buf1[6] = '\0';
                              if (strcmp(currboard,"comfortable")==0)
                              fprintf(fptr1,"<tr><td>%3d.</td><td>%s</td>"
                              "<td>%-15s</td><td>%-5s</td>"
                              ,j, brc_unread(postfile.filename)?"":"","",buf1);
 	                          else
                                fprintf(fptr1,"<tr><td>%3d.</td><td>%s</td>"
                                "<td>%-15s</td><td>%-5s</td>"
                                , j, brc_unread(postfile.filename)?"":""
                                ,postfile.owner,buf1);
                              fprintf(fptr1,"<td><a href=\"read.cgi?%s_%d\">%s</a></td></tr>\n", 
                              currboard, j, postfile.title);
                              hitnum++;
                            }
                        } /* for j */
                        close(fd);
                     } /* open fd */
                     /*** o椣çAOΨѧO̫@檺 ****/
                     fprintf(fptr1,"<tr><td>SƤFI</td><tr>\n");
                     fseek(fptr1,0,SEEK_SET);
                     fgets(buf1, 255, fptr1);/* read boards */
                     fgets(buf1, 255, fptr1);/* read search text */
                     fprintf(fptr1,"%05d\n",hitnum); /** write total record */
                     fgets(buf1, 255, fptr1);/* read begin record */
                     fid=ftell(fptr1);
                     fprintf(fptr1,"%010ld\n",fid+11); /* write begin position */
                     fseek(fptr1,0,SEEK_SET);
                }/* if isresearch **/
                
                fgets(buf1, 255, fptr1);/* read boards */
                //fprintf(cgiOut,"boards=%s<br>",buf1);
                fgets(buf1, 255, fptr1);/* read search text */
                //fprintf(cgiOut,"search=%s<br>",buf1);
                fgets(buf1, 255, fptr1);/** read hitnum **/
               //fprintf(cgiOut,"hitnum=%s<br>",buf1);
                hitnum=atoi(buf1);
                fgets(buf1, 255, fptr1);/** read startnum **/
                start=atoi(buf1);
                fgets(buf1, 255, fptr1);/** read file position **/
                fid=atol(buf1);
                if (isresearch) start=1;
                else 
                {
                    if (start>hitnum) start=hitnum;
                }
                end1 = (start + SHOWNUM > hitnum) ? hitnum : (start + SHOWNUM);
                fseek(fptr1,fid,SEEK_SET);
                /******
                fprintf(cgiOut,"start=%d,end=%d,hitnum=%d fid=%ld",
                start,end1,hitnum,fid);
                ******/
                for(j = start;j <= end1;j++) 
                {
                    fgets(buf1, 255, fptr1);/* read data */
                    fprintf(cgiOut,"%s",buf1);
                }
                if (strncmp(buf1+8,"SƤFI",12)) fid=ftell(fptr1);
                fseek(fptr1,0,SEEK_SET);
                fgets(buf1, 255, fptr1);/* read boards */
                fgets(buf1, 255, fptr1);/* read search text */
                fgets(buf1, 255, fptr1);/* read total record */
                fprintf(fptr1,"%05d\n",end1+1); /** write begin record */
                fprintf(fptr1,"%010ld\n",fid); /* write begin position */
                fprintf(cgiOut,"</table>");
                fclose(fptr1);
                
            } /* search mode **/
            else
            {
            /* Ū .DIR  */
            sprintf(buf1,BBSHOME "/boards/%s/.DIR", currboard);
            brc_initial(currboard);
            if( (fd = open( buf1, O_RDONLY )) != -1 )
            {
            lseek(fd, sizeof(struct fileheader)*(start-1), SEEK_SET);
            end1 = (start + SHOWNUM > numposts) ? numposts : (start + SHOWNUM);
           /***** }lLC@ ***/
            for(j = start;j <= end1;j++) 
            {
              read(fd,&postfile,sizeof(postfile));
              sscanf(postfile.filename,"M.%s.A",buf2);
              t1=atoi(buf2);
              strncpy(buf1,ctime(&t1)+4,6);
               buf1[6] = '\0';
              if (strcmp(currboard,"comfortable")==0)
              fprintf(cgiOut,"<tr><td>%3d.</td><td>%s</td>"
              "<td>%-15s</td><td>%-5s</td>"
             , j, brc_unread(postfile.filename)?"":"","",buf1);
 	          else
              fprintf(cgiOut,"<tr><td>%3d.</td><td>%s</td>"
              "<td>%-15s</td><td>%-5s</td>"
              , j, brc_unread(postfile.filename)?"":"",postfile.owner,buf1);
              fprintf(cgiOut,"<td><a href=\"read.cgi?%s_%d\">%s</a></td></tr>\n", 
              currboard, j, postfile.title);
            }
            fprintf(cgiOut,"</table>");
            close(fd);
           }/* endif(fd) */
           else
          { fprintf(cgiOut,"%sؿ}ҿ~I<p>",buf1);
          }

           /***** Oi ************/
          setbfile(buf1,currboard,"wenternum");
          logcnt(buf1);
         } 
         } /* else searchmode */
         else // other mode
            SSI(ptmode);
      }
      fprintf(cgiOut,"%s", pt1);
    }
   fclose(fptr2);
   
   
}
